@@ -45,8 +45,21 @@ public:
 typedef vector<CGraphParamValueNode> CGraphParamValueNodeList;
 
 #include <CNestedDataFile/anytype.h>
-template<> static const CGraphParamValueNode string_to_anytype<CGraphParamValueNode>(const string &_str,CGraphParamValueNode &ret) { const string str=s2at::remove_surrounding_quotes(_str); const size_t pos=str.find("|"); ret.x=atof(str.substr(0,pos).c_str()); ret.y=atof(str.substr(pos+1).c_str()); return ret; }
-template<> static const string anytype_to_string<CGraphParamValueNode>(const CGraphParamValueNode &any) { return "\""+anytype_to_string<double>(any.x)+"|"+anytype_to_string<double>(any.y)+"\""; }
+template<> static const CGraphParamValueNode string_to_anytype<CGraphParamValueNode>(const string &_str,CGraphParamValueNode &ret) 
+{
+	const string str=s2at::remove_surrounding_quotes(_str); 
+	const size_t pos=str.find("|"); 
+	//ret.x=atof(str.substr(0,pos).c_str());  using below to ensure locale issues aren't a problem
+	string_to_anytype(str.substr(0,pos).c_str(),ret.x);
+	//ret.y=atof(str.substr(pos+1).c_str());  using below to ensure locale issues aren't a problem
+	string_to_anytype(str.substr(pos+1).c_str(),ret.y); 
+	return ret; 
+}
+
+template<> static const string anytype_to_string<CGraphParamValueNode>(const CGraphParamValueNode &any) 
+{
+	return "\""+anytype_to_string<double>(any.x)+"|"+anytype_to_string<double>(any.y)+"\""; 
+}
 
 
 
