@@ -20,8 +20,8 @@
 
 #include "CReverseEffect.h"
 
-CReverseEffect::CReverseEffect(const CActionSound &actionSound) :
-	AAction(actionSound),
+CReverseEffect::CReverseEffect(const AActionFactory *factory,const CActionSound *actionSound) :
+	AAction(factory,actionSound),
 	allowCancel(true)
 {
 }
@@ -30,15 +30,15 @@ CReverseEffect::~CReverseEffect()
 {
 }
 
-bool CReverseEffect::doActionSizeSafe(CActionSound &actionSound,bool prepareForUndo)
+bool CReverseEffect::doActionSizeSafe(CActionSound *actionSound,bool prepareForUndo)
 {
 	unsigned channelsDoneCount=0;
-	for(unsigned i=0;i<actionSound.sound->getChannelCount();i++)
+	for(unsigned i=0;i<actionSound->sound->getChannelCount();i++)
 	{
-		if(actionSound.doChannel[i])
+		if(actionSound->doChannel[i])
 		{
-			CRezPoolAccesser a=actionSound.sound->getAudio(i);
-			CRezPoolAccesser b=actionSound.sound->getAudio(i);
+			CRezPoolAccesser a=actionSound->sound->getAudio(i);
+			CRezPoolAccesser b=actionSound->sound->getAudio(i);
 
 			// reverse by having one point go from start up to middle 
 			// and one go from end back to to middle and swap samples
@@ -46,11 +46,11 @@ bool CReverseEffect::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 
 			// ??? I could probably save CPU time by not using p1 and p2, but start+t and stop-t because it wouldn't require the add and subtruct AND storing the values back into p1 and p2
 	
-			sample_pos_t p1=actionSound.start;
-			sample_pos_t p2=actionSound.stop;
-			sample_pos_t d=actionSound.selectionLength()/2;
+			sample_pos_t p1=actionSound->start;
+			sample_pos_t p2=actionSound->stop;
+			sample_pos_t d=actionSound->selectionLength()/2;
 
-			CStatusBar statusBar(_("Reversing -- Channel ")+istring(++channelsDoneCount)+"/"+istring(actionSound.countChannels()),0,d,allowCancel);
+			CStatusBar statusBar(_("Reversing -- Channel ")+istring(++channelsDoneCount)+"/"+istring(actionSound->countChannels()),0,d,allowCancel);
 
 			for(sample_pos_t t=0;t<d;t++)
 			{
@@ -61,8 +61,8 @@ bool CReverseEffect::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 				if(statusBar.update(t))
 				{ // cancelled
 
-					sample_pos_t p1=actionSound.start;
-					sample_pos_t p2=actionSound.stop;
+					sample_pos_t p1=actionSound->start;
+					sample_pos_t p2=actionSound->stop;
 
 					statusBar.hide();
 
@@ -83,13 +83,13 @@ bool CReverseEffect::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 					// undo all previously processed channels
 					for(unsigned k=0;k<i;k++)
 					{
-						if(actionSound.doChannel[k])
+						if(actionSound->doChannel[k])
 						{
-							CRezPoolAccesser a=actionSound.sound->getAudio(k);
-							CRezPoolAccesser b=actionSound.sound->getAudio(k);
+							CRezPoolAccesser a=actionSound->sound->getAudio(k);
+							CRezPoolAccesser b=actionSound->sound->getAudio(k);
 	
-							sample_pos_t p1=actionSound.start;
-							sample_pos_t p2=actionSound.stop;
+							sample_pos_t p1=actionSound->start;
+							sample_pos_t p2=actionSound->stop;
 	
 							CStatusBar statusBar(_("Cancelling Reverse -- Channel ")+istring(--channelsDoneCount),0,d);
 	
@@ -108,26 +108,26 @@ bool CReverseEffect::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 				}
 			}
 
-			actionSound.sound->invalidatePeakData(i,actionSound.start,actionSound.stop);
+			actionSound->sound->invalidatePeakData(i,actionSound->start,actionSound->stop);
 		}
 	}
 
 	return true;
 }
 
-AAction::CanUndoResults CReverseEffect::canUndo(const CActionSound &actionSound) const
+AAction::CanUndoResults CReverseEffect::canUndo(const CActionSound *actionSound) const
 {
 	return curYes;
 }
 
-void CReverseEffect::undoActionSizeSafe(const CActionSound &actionSound)
+void CReverseEffect::undoActionSizeSafe(const CActionSound *actionSound)
 {
-	CActionSound a(actionSound);
+	CActionSound a(*actionSound);
 
 	allowCancel=false;
 	try
 	{
-		doActionSizeSafe(a,false);
+		doActionSizeSafe(&a,false);
 		allowCancel=true;
 	}
 	catch(...)
@@ -149,9 +149,9 @@ CReverseEffectFactory::~CReverseEffectFactory()
 {
 }
 
-CReverseEffect *CReverseEffectFactory::manufactureAction(const CActionSound &actionSound,const CActionParameters *actionParameters) const
+CReverseEffect *CReverseEffectFactory::manufactureAction(const CActionSound *actionSound,const CActionParameters *actionParameters) const
 {
-	return new CReverseEffect(actionSound);
+	return new CReverseEffect(this,actionSound);
 }
 
 
