@@ -82,7 +82,7 @@ class CLevelMeter : public FXHorizontalFrame
 {
 	FXDECLARE(CLevelMeter);
 public:
-	CLevelMeter::CLevelMeter(FXComposite *parent) :
+	CLevelMeter(FXComposite *parent) :
 		FXHorizontalFrame(parent,LAYOUT_FILL_X|LAYOUT_FIX_HEIGHT|LAYOUT_TOP | FRAME_NONE,0,0,0,0, 0,0,0,0, 0,0),
 		statusFont(getApp()->getNormalFont()),
 		canvas(new FXCanvas(this,this,ID_CANVAS,FRAME_NONE | LAYOUT_FILL_X|LAYOUT_FILL_Y)),
@@ -121,7 +121,7 @@ public:
 
 	}
 
-	CLevelMeter::~CLevelMeter()
+	~CLevelMeter()
 	{
 		delete statusFont;
 	}
@@ -133,7 +133,7 @@ public:
 		setHeight(max(statusFont->getFontHeight(),MIN_METER_HEIGHT)); // make meter only as tall as necessary (also with a defined minimum)
 	}
 
-	long CLevelMeter::onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		FXDCWindow dc(canvas);
 
@@ -327,7 +327,7 @@ class CBalanceMeter : public FXHorizontalFrame
 {
 	FXDECLARE(CBalanceMeter);
 public:
-	CBalanceMeter::CBalanceMeter(FXComposite *parent) :
+	CBalanceMeter(FXComposite *parent) :
 		FXHorizontalFrame(parent,LAYOUT_FILL_X|LAYOUT_FIX_HEIGHT | FRAME_NONE, 0,0,0,0, 0,0,0,0, 0,0),
 		statusFont(getApp()->getNormalFont()),
 		leftLabel(new FXLabel(this,"-1.0")),
@@ -361,7 +361,7 @@ public:
 
 	}
 
-	CBalanceMeter::~CBalanceMeter()
+	~CBalanceMeter()
 	{
 		delete statusFont;
 	}
@@ -372,7 +372,7 @@ public:
 		setHeight(max(statusFont->getFontHeight(),MIN_METER_HEIGHT)); // make meter only as tall as necessary (also with a defined minimum)
 	}
 
-	long CBalanceMeter::onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		FXDCWindow dc(canvas);
 
@@ -478,7 +478,7 @@ class CStereoPhaseMeter : public FXHorizontalFrame
 {
 	FXDECLARE(CStereoPhaseMeter);
 public:
-	CStereoPhaseMeter::CStereoPhaseMeter(FXComposite *parent,sample_t *_samplingBuffer,size_t _samplingNFrames,unsigned _samplingNChannels,unsigned _samplingLeftChannel,unsigned _samplingRightChannel) :
+	CStereoPhaseMeter(FXComposite *parent,sample_t *_samplingBuffer,size_t _samplingNFrames,unsigned _samplingNChannels,unsigned _samplingLeftChannel,unsigned _samplingRightChannel) :
 		FXHorizontalFrame(parent,LAYOUT_RIGHT|LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0, 0,0),
 		canvasFrame(new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 2,2,2,2, 0,1)),
 			canvas(new FXBackBufferedCanvas(canvasFrame,this,ID_CANVAS,LAYOUT_FILL_X|LAYOUT_FILL_Y)),
@@ -519,19 +519,19 @@ public:
 		statusFont=new FXFont(getApp(),d);
 	}
 
-	CStereoPhaseMeter::~CStereoPhaseMeter()
+	~CStereoPhaseMeter()
 	{
 		delete statusFont;
 	}
 
-	long CStereoPhaseMeter::onZoomDial(FXObject *sender,FXSelector sel,void *ptr)
+	long onZoomDial(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		zoom=((float)zoomDial->getValue())/100.0f;
 		canvas->update(); // not really necessary since we're doing it several times a second anyway
 		return 1;
 	}
 
-	long CStereoPhaseMeter::onResize(FXObject *sender,FXSelector sel,void *ptr)
+	long onResize(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		// make square
 		resize(getHeight()+getHSpacing()+zoomDial->getWidth(),getHeight());
@@ -540,7 +540,7 @@ public:
 		return 1;
 	}
 
-	long CStereoPhaseMeter::onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		FXColor *data=(FXColor *)canvas->getBackBufferData();
 
@@ -730,7 +730,7 @@ class CAnalyzer : public FXHorizontalFrame
 {
 	FXDECLARE(CAnalyzer);
 public:
-	CAnalyzer::CAnalyzer(FXComposite *parent) :
+	CAnalyzer(FXComposite *parent) :
 		FXHorizontalFrame(parent,LAYOUT_RIGHT|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0, 0,0),
 		canvasFrame(new FXVerticalFrame(this,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 2,2,2,2, 0,1)),
 			canvas(new FXBackBufferedCanvas(canvasFrame,this,ID_CANVAS,LAYOUT_FILL_X|LAYOUT_FILL_Y)),
@@ -763,25 +763,25 @@ public:
 		canvasFrame->setWidth(150);
 	}
 
-	CAnalyzer::~CAnalyzer()
+	~CAnalyzer()
 	{
 		delete statusFont;
 	}
 
-	long CAnalyzer::onZoomDial(FXObject *sender,FXSelector sel,void *ptr)
+	long onZoomDial(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		zoom=zoomDial->getValue();
 		canvas->update(); // not really necessary since we're doing it several times a second anyway
 		return 1;
 	}
 
-	long CAnalyzer::onZoomDialDefault(FXObject *sender,FXSelector sel,void *ptr)
+	long onZoomDialDefault(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		zoomDial->setValue(25);
 		return onZoomDial(sender,sel,ptr);
 	}
 
-	long CAnalyzer::onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasPaint(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		FXDC &dc=*((FXDC*)ptr); // back buffered canvases send the DC to draw onto in ptr
 
@@ -865,19 +865,19 @@ public:
 		return 1;
 	}
 
-	long CAnalyzer::onCanvasEnter(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasEnter(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		drawBarFreq=true;
 		return onCanvasMotion(sender,sel,ptr);
 	}
 
-	long CAnalyzer::onCanvasLeave(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasLeave(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		drawBarFreq=false;
 		return onCanvasMotion(sender,sel,ptr);
 	}
 
-	long CAnalyzer::onCanvasMotion(FXObject *sender,FXSelector sel,void *ptr)
+	long onCanvasMotion(FXObject *sender,FXSelector sel,void *ptr)
 	{
 		barFreqIndex=((FXEvent *)ptr)->win_x/ANALYZER_BAR_WIDTH;
 		return 1;
