@@ -48,14 +48,14 @@ CRawDialog::CRawDialog(FXWindow *mainWindow) :
 	FXComposite *main=new FXMatrix(getFrame(),2,MATRIX_BY_COLUMNS,LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	FXComboBox *combo;
 
-	new FXLabel(main,_("Channels:"),NULL,LABEL_NORMAL|LAYOUT_RIGHT);
+	channelsCountLabel=new FXLabel(main,_("Channels:"),NULL,LABEL_NORMAL|LAYOUT_RIGHT);
 	combo=channelsCountComboBox=new FXComboBox(main,10,NULL,0,COMBOBOX_NORMAL|FRAME_SUNKEN|FRAME_THICK);
 	combo->setNumVisible(8);
 		for(unsigned t=1;t<=MAX_CHANNELS;t++)
 			combo->appendItem(istring(t).c_str());
 		combo->setCurrentItem(1); // stereo
 
-	new FXLabel(main,_("Sample Rate:"),NULL,LABEL_NORMAL|LAYOUT_RIGHT);
+	sampleRateLabel=new FXLabel(main,_("Sample Rate:"),NULL,LABEL_NORMAL|LAYOUT_RIGHT);
 	combo=sampleRateComboBox=new FXComboBox(main,10,NULL,0,COMBOBOX_NORMAL|FRAME_SUNKEN|FRAME_THICK);
 	combo->setNumVisible(9);
 		combo->appendItem("4000");
@@ -108,17 +108,26 @@ CRawDialog::~CRawDialog()
 {
 }
 
-bool CRawDialog::show(AFrontendHooks::RawParameters &parameters,bool showOffsetAndLengthParameters)
+bool CRawDialog::show(AFrontendHooks::RawParameters &parameters,bool showLoadRawParameters)
 {
-	if(showOffsetAndLengthParameters)
+	if(showLoadRawParameters)
 	{
+		channelsCountLabel->show();
+		channelsCountComboBox->show();
+		sampleRateLabel->show();
+		sampleRateComboBox->show();
 		offsetLabel->show();
 		offsetFrame->show();
 		lengthLabel->show();
 		lengthFrame->show();
+		
 	}
 	else
 	{
+		channelsCountLabel->hide();
+		channelsCountComboBox->hide();
+		sampleRateLabel->hide();
+		sampleRateComboBox->hide();
 		offsetLabel->hide();
 		offsetFrame->hide();
 		lengthLabel->hide();
