@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
@@ -45,8 +45,7 @@
 /* Using locations.  */
 #define YYLSP_NEEDED 1
 
-/* If NAME_PREFIX is specified substitute the variables and functions
-   names.  */
+/* Substitute the variable and function names.  */
 #define yyparse cfg_parse
 #define yylex   cfg_lex
 #define yyerror cfg_error
@@ -231,8 +230,8 @@ typedef struct YYLTYPE
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 236 "cfg.tab.c"
+/* Line 213 of yacc.c.  */
+#line 235 "cfg.tab.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -247,14 +246,10 @@ typedef struct YYLTYPE
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -664,20 +659,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -700,19 +728,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Token, Value, Location);	\
+                  Type, Value, Location);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -779,8 +801,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -798,10 +819,6 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -885,15 +902,17 @@ yysymprint (yyoutput, yytype, yyvaluep, yylocationp)
   (void) yylocationp;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+  YY_LOCATION_PRINT (yyoutput, *yylocationp);
+  fprintf (yyoutput, ": ");
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -909,10 +928,11 @@ yysymprint (yyoutput, yytype, yyvaluep, yylocationp)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep, YYLTYPE *yylocationp)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, YYLTYPE *yylocationp)
 #else
 static void
-yydestruct (yytype, yyvaluep, yylocationp)
+yydestruct (yymsg, yytype, yyvaluep, yylocationp)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
     YYLTYPE *yylocationp;
@@ -922,6 +942,10 @@ yydestruct (yytype, yyvaluep, yylocationp)
   (void) yyvaluep;
   (void) yylocationp;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
 
@@ -949,15 +973,15 @@ int yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
 int yynerrs;
-/* Location data for the lookahead symbol.  */
+/* Location data for the look-ahead symbol.  */
 YYLTYPE yylloc;
 
 
@@ -990,7 +1014,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -1015,7 +1039,8 @@ yyparse ()
   YYLTYPE yylsa[YYINITDEPTH];
   YYLTYPE *yyls = yylsa;
   YYLTYPE *yylsp;
-  YYLTYPE *yylerrsp;
+  /* The locations where the error started and ended. */
+  YYLTYPE yyerror_range[2];
 
 #define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
 
@@ -1045,6 +1070,15 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
   yylsp = yyls;
+#if YYLTYPE_IS_TRIVIAL
+  /* Initialize the default location before parsing starts.  */
+  yylloc.first_line   = yylloc.last_line   = 1;
+  yylloc.first_column = yylloc.last_column = 0;
+#endif
+
+
+  yyvsp[0] = yylval;
+    yylsp[0] = yylloc;
 
   goto yysetstate;
 
@@ -1135,18 +1169,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1161,7 +1195,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1181,8 +1215,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1258,11 +1292,11 @@ yyreduce:
 #line 172 "../../../src/misc/CNestedDataFile/cfg.y"
     { /* mid-rule action */
 
-		checkForDupMember(yylsp[-1].first_line,yyvsp[-1].stringValue);
+		checkForDupMember((yylsp[-1]).first_line,(yyvsp[-1].stringValue));
 
-		scopeStack.push(yyvsp[-1].stringValue);
+		scopeStack.push((yyvsp[-1].stringValue));
 
-		free(yyvsp[-1].stringValue);
+		free((yyvsp[-1].stringValue));
 
 		/* now continue parsing for new scope's body */
 	}
@@ -1278,91 +1312,91 @@ yyreduce:
   case 14:
 #line 210 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		checkForDupMember(yylsp[-4].first_line,yyvsp[-4].stringValue);
-		if(yyvsp[-1].variant->type==CNestedDataFile::ktValue)
-			CNestedDataFile::parseTree->prvCreateKey(getCurrentScope()+yyvsp[-4].stringValue,0,*yyvsp[-1].variant,CNestedDataFile::parseTree->root);
+		checkForDupMember((yylsp[-4]).first_line,(yyvsp[-4].stringValue));
+		if((yyvsp[-1].variant)->type==CNestedDataFile::ktValue)
+			CNestedDataFile::parseTree->prvCreateKey(getCurrentScope()+(yyvsp[-4].stringValue),0,*(yyvsp[-1].variant),CNestedDataFile::parseTree->root);
 		else
-			yyerror(yylsp[-2],"assigning an invalid typed value to an identifier");
+			yyerror((yylsp[-2]),"assigning an invalid typed value to an identifier");
 
-		delete yyvsp[-1].variant;
-		free(yyvsp[-4].stringValue);
+		delete (yyvsp[-1].variant);
+		free((yyvsp[-4].stringValue));
 	}
     break;
 
   case 15:
 #line 221 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		cfg_includeFile(yyvsp[0].stringValue);
-		free(yyvsp[0].stringValue);
+		cfg_includeFile((yyvsp[0].stringValue));
+		free((yyvsp[0].stringValue));
 	}
     break;
 
   case 17:
 #line 230 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=strdup("{}");
+		(yyval.stringValue)=strdup("{}");
 	}
     break;
 
   case 18:
 #line 234 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=(char *)malloc((1+strlen(yyvsp[-1].stringValue)+1)+1);
-		strcpy(yyval.stringValue,"{");
-		strcat(yyval.stringValue,yyvsp[-1].stringValue);
-		strcat(yyval.stringValue,"}");
-		free(yyvsp[-1].stringValue);
+		(yyval.stringValue)=(char *)malloc((1+strlen((yyvsp[-1].stringValue))+1)+1);
+		strcpy((yyval.stringValue),"{");
+		strcat((yyval.stringValue),(yyvsp[-1].stringValue));
+		strcat((yyval.stringValue),"}");
+		free((yyvsp[-1].stringValue));
 	}
     break;
 
   case 19:
 #line 245 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=strdup(yyvsp[0].variant->stringValue.c_str());
-		delete yyvsp[0].variant;
+		(yyval.stringValue)=strdup((yyvsp[0].variant)->stringValue.c_str());
+		delete (yyvsp[0].variant);
 	}
     break;
 
   case 20:
 #line 251 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=(char *)malloc((strlen(yyvsp[-2].stringValue)+1+yyvsp[0].variant->stringValue.size())+1);
-		strcpy(yyval.stringValue,yyvsp[-2].stringValue);
-		strcat(yyval.stringValue,",");
-		strcat(yyval.stringValue,yyvsp[0].variant->stringValue.c_str());
+		(yyval.stringValue)=(char *)malloc((strlen((yyvsp[-2].stringValue))+1+(yyvsp[0].variant)->stringValue.size())+1);
+		strcpy((yyval.stringValue),(yyvsp[-2].stringValue));
+		strcat((yyval.stringValue),",");
+		strcat((yyval.stringValue),(yyvsp[0].variant)->stringValue.c_str());
 
-		free(yyvsp[-2].stringValue);
-		delete yyvsp[0].variant;
+		free((yyvsp[-2].stringValue));
+		delete (yyvsp[0].variant);
 	}
     break;
 
   case 21:
 #line 263 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=strdup("");
+		(yyval.stringValue)=strdup("");
 	}
     break;
 
   case 22:
 #line 267 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=yyvsp[-2].stringValue;
+		(yyval.stringValue)=(yyvsp[-2].stringValue);
 	}
     break;
 
   case 23:
 #line 278 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=new CNestedDataFile::CVariant(yyvsp[0].stringValue);
-		free(yyvsp[0].stringValue);
+		(yyval.variant)=new CNestedDataFile::CVariant((yyvsp[0].stringValue));
+		free((yyvsp[0].stringValue));
 	}
     break;
 
   case 24:
 #line 283 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=new CNestedDataFile::CVariant(anytype_to_string<string>(yyvsp[0].stringValue));
-		free(yyvsp[0].stringValue);
+		(yyval.variant)=new CNestedDataFile::CVariant(anytype_to_string<string>((yyvsp[0].stringValue)));
+		free((yyvsp[0].stringValue));
 	}
     break;
 
@@ -1370,30 +1404,30 @@ yyreduce:
 #line 288 "../../../src/misc/CNestedDataFile/cfg.y"
     {
 		/* having gettext(...) around a string simply causes an entry to be created in the rezound.pot file */
-		yyval.variant=new CNestedDataFile::CVariant(anytype_to_string<string>(yyvsp[-1].stringValue));
-		free(yyvsp[-1].stringValue);
+		(yyval.variant)=new CNestedDataFile::CVariant(anytype_to_string<string>((yyvsp[-1].stringValue)));
+		free((yyvsp[-1].stringValue));
 	}
     break;
 
   case 26:
 #line 294 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=new CNestedDataFile::CVariant("true");
+		(yyval.variant)=new CNestedDataFile::CVariant("true");
 	}
     break;
 
   case 27:
 #line 298 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=new CNestedDataFile::CVariant("false");
+		(yyval.variant)=new CNestedDataFile::CVariant("false");
 	}
     break;
 
   case 28:
 #line 304 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=new CNestedDataFile::CVariant(yyvsp[0].stringValue);
-		free(yyvsp[0].stringValue);
+		(yyval.variant)=new CNestedDataFile::CVariant((yyvsp[0].stringValue));
+		free((yyvsp[0].stringValue));
 	}
     break;
 
@@ -1402,24 +1436,24 @@ yyreduce:
     {
 		if(CNestedDataFile::parseTree==NULL)
 		{
-			yyval.variant=new CNestedDataFile::CVariant("");
+			(yyval.variant)=new CNestedDataFile::CVariant("");
 		}
 		else
 		{
 			CNestedDataFile::CVariant *value;
-			if(!CNestedDataFile::parseTree->findVariantNode(value,yyvsp[0].stringValue,0,false,CNestedDataFile::parseTree->root))
+			if(!CNestedDataFile::parseTree->findVariantNode(value,(yyvsp[0].stringValue),0,false,CNestedDataFile::parseTree->root))
 			{
-				cfg_error(yylsp[0],("symbol not found: '"+string(yyvsp[0].stringValue)+"'").c_str());
+				cfg_error((yylsp[0]),("symbol not found: '"+string((yyvsp[0].stringValue))+"'").c_str());
 				value=new CNestedDataFile::CVariant("");
 			}
 
 			switch(value->type)
 			{
 			case CNestedDataFile::ktValue:
-				yyval.variant=new CNestedDataFile::CVariant(value->stringValue);
+				(yyval.variant)=new CNestedDataFile::CVariant(value->stringValue);
 				break;
 			case CNestedDataFile::ktScope:
-				cfg_error(yylsp[0],("symbol resolves to a scope: '"+string(yyvsp[0].stringValue)+"'").c_str());
+				cfg_error((yylsp[0]),("symbol resolves to a scope: '"+string((yyvsp[0].stringValue))+"'").c_str());
 				value=new CNestedDataFile::CVariant("");
 				break;
 			default:
@@ -1427,14 +1461,14 @@ yyreduce:
 			}
 		}
 
-		free(yyvsp[0].stringValue);
+		free((yyvsp[0].stringValue));
 	}
     break;
 
   case 30:
 #line 344 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=yyvsp[-1].variant;
+		(yyval.variant)=(yyvsp[-1].variant);
 	}
     break;
 
@@ -1442,25 +1476,25 @@ yyreduce:
 #line 351 "../../../src/misc/CNestedDataFile/cfg.y"
     {
 		yyclearin;
-		yyval.variant=new CNestedDataFile::CVariant("");
+		(yyval.variant)=new CNestedDataFile::CVariant("");
 	}
     break;
 
   case 32:
 #line 359 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 33:
 #line 362 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=yyvsp[0].variant;
-		if(yyvsp[0].variant->type!=CNestedDataFile::ktValue)
-			cfg_error(yylsp[0],"invalid operand");
+		(yyval.variant)=(yyvsp[0].variant);
+		if((yyvsp[0].variant)->type!=CNestedDataFile::ktValue)
+			cfg_error((yylsp[0]),"invalid operand");
 		else
 		{
 			double x;
-			yyval.variant->stringValue=strdup(anytype_to_string<double>(+string_to_anytype<double>(yyval.variant->stringValue,x)).c_str());
+			(yyval.variant)->stringValue=strdup(anytype_to_string<double>(+string_to_anytype<double>((yyval.variant)->stringValue,x)).c_str());
 		}
 	}
     break;
@@ -1468,142 +1502,142 @@ yyreduce:
   case 34:
 #line 373 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.variant=yyvsp[0].variant;
-		if(yyvsp[0].variant->type!=CNestedDataFile::ktValue)
-			cfg_error(yylsp[0],"invalid operand");
+		(yyval.variant)=(yyvsp[0].variant);
+		if((yyvsp[0].variant)->type!=CNestedDataFile::ktValue)
+			cfg_error((yylsp[0]),"invalid operand");
 		else
 		{
 			double x;
-			yyval.variant->stringValue=strdup(anytype_to_string<double>(-string_to_anytype<double>(yyval.variant->stringValue,x)).c_str());
+			(yyval.variant)->stringValue=strdup(anytype_to_string<double>(-string_to_anytype<double>((yyval.variant)->stringValue,x)).c_str());
 		}
 	}
     break;
 
   case 35:
 #line 387 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 36:
 #line 388 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,*) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),*) }
     break;
 
   case 37:
 #line 389 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,/) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),/) }
     break;
 
   case 38:
 #line 390 "../../../src/misc/CNestedDataFile/cfg.y"
-    { double x1,x2; VERIFY_TYPE(yylsp[-2],yyvsp[-2].variant) VERIFY_TYPE(yylsp[0],yyvsp[0].variant) yyval.variant=yyvsp[-2].variant; yyval.variant->stringValue= strdup( anytype_to_string<double>(fmod(string_to_anytype<double>(yyval.variant->stringValue,x1),string_to_anytype<double>(yyvsp[0].variant->stringValue,x2))).c_str() ); delete yyvsp[0].variant; }
+    { double x1,x2; VERIFY_TYPE((yylsp[-2]),(yyvsp[-2].variant)) VERIFY_TYPE((yylsp[0]),(yyvsp[0].variant)) (yyval.variant)=(yyvsp[-2].variant); (yyval.variant)->stringValue= strdup( anytype_to_string<double>(fmod(string_to_anytype<double>((yyval.variant)->stringValue,x1),string_to_anytype<double>((yyvsp[0].variant)->stringValue,x2))).c_str() ); delete (yyvsp[0].variant); }
     break;
 
   case 39:
 #line 395 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 40:
 #line 396 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,+) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),+) }
     break;
 
   case 41:
 #line 397 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,-) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),-) }
     break;
 
   case 42:
 #line 402 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 43:
 #line 403 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,<=) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),<=) }
     break;
 
   case 44:
 #line 404 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,>=) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),>=) }
     break;
 
   case 45:
 #line 405 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,<) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),<) }
     break;
 
   case 46:
 #line 406 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,>) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),>) }
     break;
 
   case 47:
 #line 410 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 48:
 #line 411 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,==) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),==) }
     break;
 
   case 49:
 #line 412 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,!=) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),!=) }
     break;
 
   case 50:
 #line 416 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 51:
 #line 417 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,&&) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),&&) }
     break;
 
   case 52:
 #line 421 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 53:
 #line 422 "../../../src/misc/CNestedDataFile/cfg.y"
-    { BINARY_EXPR(yyval.variant,yylsp[-2],yyvsp[-2].variant,yylsp[0],yyvsp[0].variant,||) }
+    { BINARY_EXPR((yyval.variant),(yylsp[-2]),(yyvsp[-2].variant),(yylsp[0]),(yyvsp[0].variant),||) }
     break;
 
   case 54:
 #line 427 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 55:
 #line 428 "../../../src/misc/CNestedDataFile/cfg.y"
-    { double x; VERIFY_TYPE(yylsp[-4],yyvsp[-4].variant) yyval.variant=(string_to_anytype<double>(yyvsp[-4].variant->stringValue,x) ? ((delete yyvsp[0].variant),yyvsp[-2].variant) : ((delete yyvsp[-2].variant),yyvsp[0].variant)); delete yyvsp[-4].variant; }
+    { double x; VERIFY_TYPE((yylsp[-4]),(yyvsp[-4].variant)) (yyval.variant)=(string_to_anytype<double>((yyvsp[-4].variant)->stringValue,x) ? ((delete (yyvsp[0].variant)),(yyvsp[-2].variant)) : ((delete (yyvsp[-2].variant)),(yyvsp[0].variant))); delete (yyvsp[-4].variant); }
     break;
 
   case 56:
 #line 433 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 57:
 #line 440 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=yyvsp[0].stringValue;
+		(yyval.stringValue)=(yyvsp[0].stringValue);
 	}
     break;
 
   case 58:
 #line 444 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		yyval.stringValue=(char *)realloc(yyval.stringValue,strlen(yyval.stringValue)+1+strlen(yyvsp[0].stringValue)+1);
-		strcat(yyval.stringValue,CNestedDataFile::delim.c_str());
-		strcat(yyval.stringValue,yyvsp[0].stringValue);
+		(yyval.stringValue)=(char *)realloc((yyval.stringValue),strlen((yyval.stringValue))+1+strlen((yyvsp[0].stringValue))+1);
+		strcat((yyval.stringValue),CNestedDataFile::delim.c_str());
+		strcat((yyval.stringValue),(yyvsp[0].stringValue));
 
-		free(yyvsp[0].stringValue);
+		free((yyvsp[0].stringValue));
 	}
     break;
 
@@ -1625,22 +1659,22 @@ yyreduce:
   case 62:
 #line 465 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		CNestedDataFile::s2at_return_value.push_back(yyvsp[0].variant->stringValue);
-		delete yyvsp[0].variant;
+		CNestedDataFile::s2at_return_value.push_back((yyvsp[0].variant)->stringValue);
+		delete (yyvsp[0].variant);
 	}
     break;
 
   case 63:
 #line 470 "../../../src/misc/CNestedDataFile/cfg.y"
     {
-		CNestedDataFile::s2at_return_value.push_back(yyvsp[0].variant->stringValue);
-		delete yyvsp[0].variant;
+		CNestedDataFile::s2at_return_value.push_back((yyvsp[0].variant)->stringValue);
+		delete (yyvsp[0].variant);
 	}
     break;
 
   case 64:
 #line 478 "../../../src/misc/CNestedDataFile/cfg.y"
-    { yyval.variant=yyvsp[0].variant; }
+    { (yyval.variant)=(yyvsp[0].variant); }
     break;
 
   case 65:
@@ -1651,8 +1685,8 @@ yyreduce:
 
     }
 
-/* Line 1010 of yacc.c.  */
-#line 1656 "cfg.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1690 "cfg.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1748,11 +1782,11 @@ yyerrlab:
 	yyerror ("syntax error");
     }
 
-  yylerrsp = yylsp;
+  yyerror_range[0] = yylloc;
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1762,23 +1796,22 @@ yyerrlab:
 	  if (yychar == YYEOF)
 	     for (;;)
 	       {
+                 yyerror_range[0] = *yylsp;
 		 YYPOPSTACK;
 		 if (yyssp == yyss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct ("Error: popping",
+                             yystos[*yyssp], yyvsp, yylsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval, &yylloc);
+	  yydestruct ("Error: discarding", yytoken, &yylval, &yylloc);
 	  yychar = YYEMPTY;
-	  *++yylerrsp = yylloc;
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1795,12 +1828,11 @@ yyerrorlab:
      goto yyerrorlab;
 #endif
 
+  yyerror_range[0] = yylsp[1-yylen];
+  yylsp -= yylen;
   yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
-  yylerrsp = yylsp;
-  *++yylerrsp = yyloc;
-  yylsp -= yylen;
   goto yyerrlab1;
 
 
@@ -1828,8 +1860,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp, yylsp);
+      yyerror_range[0] = *yylsp;
+      yydestruct ("Error: popping", yystos[yystate], yyvsp, yylsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1838,12 +1870,17 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
-  YYLLOC_DEFAULT (yyloc, yylsp, yylerrsp - yylsp);
+
+  yyerror_range[1] = yylloc;
+  /* Using YYLLOC is tempting, but would change the location of
+     the look-ahead.  YYLOC is available though. */
+  YYLLOC_DEFAULT (yyloc, yyerror_range - 1, 2);
   *++yylsp = yyloc;
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -1859,6 +1896,9 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
+  yydestruct ("Error: discarding lookahead",
+              yytoken, &yylval, &yylloc);
+  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
